import { faPen } from '@fortawesome/free-solid-svg-icons';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';

import Tag from '../components/Tag';
import colors from '../utils/colors';
import fontawesome from '../utils/fontawesome';

const defaultProps = {
  enableSubtitle1: true,
  enableSubtitle2: true,
  enableIconArrow: true,
  enableIconPen: true,
  enableTag: true,
  tagContent: ['tag1', 'tag2'],
  titleContent: 'Título',
  subtitle1Content: 'Subtítulo 1',
  subtitle2Content: 'Subtítulo 2',
  onClickArrow: () => {
    console.log('clicou');
  },
  onClickPen: () => {
    console.log('clicou');
  },
};

type CardProps = {
  enableSubtitle1?: boolean;
  enableSubtitle2?: boolean;
  enableIconArrow?: boolean;
  enableIconPen?: boolean;
  enableTag?: boolean;
  tagContent?: Array<string>;
  titleContent?: string;
  subtitle1Content?: string;
  subtitle2Content?: string;
  onClickArrow?: () => void;
  onClickPen?: () => void;
} & typeof defaultProps;

function CardLista(props: CardProps) {
  const {
    enableSubtitle1,
    enableSubtitle2,
    enableIconArrow,
    enableIconPen,
    enableTag,
    tagContent,
    titleContent,
    subtitle1Content,
    subtitle2Content,
    onClickArrow,
    onClickPen,
  } = props;

  return (
    <div style={styles.card}>
      {/*  Fora retirados className="card" className="row" */}
      <div style={styles.row}>
        <p style={styles.title}>{titleContent}</p>
        {enableSubtitle1 && <p style={styles.subtitle}>{subtitle1Content}</p>}
        {enableSubtitle2 && <p style={styles.subtitle}>{subtitle2Content}</p>}
        <div style={styles.tagContainer}>
          {enableTag &&
            tagContent.map(tag => {
              return <Tag text={tag} textSize="12px" />;
            })}
        </div>
      </div>
      <div style={styles.rightRow}>
        <div>
          {enableIconArrow && (
            <FontAwesomeIcon
              icon={fontawesome.icons.faArrowRight}
              style={enableIconPen ? styles.iconArrowSpace : styles.iconArrow}
              onClick={onClickArrow}
            />
          )}
        </div>

        <div>
          {enableIconPen && (
            <FontAwesomeIcon
              icon={faPen}
              style={styles.iconPen}
              onClick={onClickPen}
            />
          )}
        </div>
      </div>
    </div>
  );
}

const styles = {
  tagContainer: {
    display: 'flex',
    flexDirection: 'row' as const,
    padding: 0,
    paddingTop: '0.625rem',
    margin: 0,
  },
  card: {
    display: 'flex',
    flexDirection: 'row' as const,
    padding: '0.313rem',
    background: '#FFFFFF',
    boxShadow: '0.094rem 0.156rem 0.256rem rgba(0, 0, 0, 0.25)',
    borderRadius: '0.313rem',
  },
  row: {
    paddingLeft: '0.313rem',
    flexGrow: 100,
    margin: '0.188rem',
    flexBasis: '90%',
    alignItems: 'space-between',
  },
  rightRow: {
    padding: '0.625rem',
    flexGrow: 1,
    margin: '0.188rem 0.625rem 0.188rem 0.188rem',
    flexDirection: 'column' as const,
    flexWrap: 'wrap' as const,
  },
  title: {
    fontStyle: 'poppins',
    fontWeight: 500,
    fontSize: '1.25rem',
    marginBottom: 0,
    padding: 0,
  },
  subtitle: {
    fontStyle: 'poppins',
    fontWeight: 400,
    fontSize: '1rem',
    margin: 0,
    padding: 0,
  },
  iconPen: {
    fontSize: '1.563rem',
    marginBottom: 0,
    padding: 0,
  },
  iconArrow: {
    fontSize: '1.875rem',
  },
  iconArrowSpace: {
    fontSize: '1.875rem',
    marginBottom: '1rem',
  },
};

CardLista.defaultProps = defaultProps;

export default CardLista;
