import { useEffect, useState } from 'react';
import { useNavigate } from 'react-router-dom';

import { ButtonCard } from '../components';
import TextField from '../components/TextField';
import api from '../services/api';
import colors from '../utils/colors';
import fontawesome from '../utils/fontawesome';
import Modal from './Modal';

const defaultProps = {
  className: 'formComponent',
  professor: false,
  specialist: false,
  onClickSubmit: () => {
    console.log();
  },
  onClickX: () => {
    console.log('x');
  },
  closeModalChangeScreen: () => {
    console.log('change screen');
  },
};

type formComponentProps = {
  className?: string;
  professor?: boolean;
  specialist?: boolean;
  onClickSubmit?: () => void;
  onClickX?: () => void;
  closeModalChangeScreen?: () => void;
} & typeof defaultProps;

function FormComponent(props: formComponentProps) {
  const navigate = useNavigate();
  const {
    className,
    professor,
    specialist,
    onClickSubmit,
    onClickX,
    closeModalChangeScreen,
  } = props;

  const styles = {
    container: {
      flex: 1,
      background: colors.theme.background,
      minHeight: '100vh',
      textAlign: 'center' as const,
    },
    modal: {
      position: 'absolute' as const,
      alignself: 'center',
      justifyContent: 'center',
      top: 0,
      left: 0,
      right: 0,
      bottom: 0,
    },
    buttons: {
      display: 'flex',
      justifyContent: 'center',
      marginTop: '5em',
    },
    button: {
      margin: 10,
    },
    wrapper: {
      alignItems: 'center',
      textAlign: 'center' as const,
      display: 'flex',
      justifyContent: 'center',
      marginTop: '5em',
    },
  };

  const [modalEmpty, setModalEmpty] = useState(false);
  const [modalCancel, setModalCancel] = useState(false);
  const [modalSuccess, setModalSuccess] = useState(false);

  const toggleModalEmpty = () => {
    setModalEmpty(!modalEmpty);
  };
  const toggleModalCancel = () => {
    setModalCancel(!modalCancel);
  };
  const toggleModalSuccess = () => {
    setModalSuccess(!modalSuccess);
  };

  const [user, setUser] = useState('');
  const [name, setName] = useState('');
  const [phone, setPhone] = useState('');
  const [email, setEmail] = useState('');
  const [cpf, setCpf] = useState('');
  const [specialization, setSpecialization] = useState('');
  const [discipline, setDiscipline] = useState('');

  useEffect(() => {
    api
      .post('http://localhost:4000/api/v1/users/teachers', {
        email,
        name,
        phone_number: phone,
        document: cpf,
        password: '123',
        subject: discipline,
      })
      .then(response => setUser(response.data))
      .catch(err => {
        console.error(`ops! ocorreu um erro${err}`);
      });
  }, []);

  return (
    <div className={className} style={{ padding: '20px' }}>
      <div style={{ display: 'flex', justifyContent: 'center' }}>
        <TextField
          placeholder="Nome Completo"
          onChange={event => setName(event.target.value)}
        />
      </div>
      <div style={{ display: 'flex', justifyContent: 'center' }}>
        <TextField
          placeholder="Telefone"
          onChange={event => setPhone(event.target.value)}
        />
      </div>

      <div style={{ display: 'flex', justifyContent: 'center' }}>
        <TextField
          placeholder="E-mail"
          onChange={event => setEmail(event.target.value)}
        />
      </div>
      <div style={{ display: 'flex', justifyContent: 'center' }}>
        <TextField
          placeholder="CPF"
          onChange={event => setCpf(event.target.value)}
        />
      </div>

      {specialist && (
        <div style={{ display: 'flex', justifyContent: 'center' }}>
          <TextField
            placeholder="Especialização"
            onChange={event => setSpecialization(event.target.value)}
          />
        </div>
      )}
      {professor && (
        <div style={{ display: 'flex', justifyContent: 'center' }}>
          <TextField
            placeholder="Disciplina (Opcional)"
            onChange={event => setDiscipline(event.target.value)}
          />
        </div>
      )}

      <div style={styles.wrapper}>
        <div style={{ marginRight: '1.5em' }}>
          <ButtonCard
            width="8.28em"
            height="3.29em"
            text=""
            icon={fontawesome.icons.faXmark}
            sizeIcon="2.25em"
            backgroundColor={colors.theme.blue}
            iconWidth="100%"
            onClick={() => {
              if (
                cpf.length !== 11 ||
                phone.length !== 11 ||
                name.length === 0 ||
                email.length === 0 ||
                !email.includes('@') ||
                (specialist && specialization.length === 0)
              ) {
                toggleModalEmpty();
              } else {
                toggleModalSuccess();
                onClickSubmit();
              }
            }}
          />
        </div>
        <ButtonCard
          width="8.28em"
          height="3.29em"
          text=""
          icon={fontawesome.icons.faCheck}
          sizeIcon="2.25em"
          backgroundColor={colors.theme.blue}
          iconWidth="100%"
          onClick={() => {
            if (
              cpf.length !== 11 ||
              phone.length !== 11 ||
              name.length === 0 ||
              email.length === 0 ||
              !email.includes('@') ||
              (specialist && specialization.length === 0)
            ) {
              toggleModalEmpty();
            } else {
              toggleModalSuccess();
              onClickSubmit();
            }
          }}
        />
      </div>
      {modalEmpty && (
        <div style={styles.modal}>
          <Modal
            text="Preencha todos os campos corretamente."
            hasWarningSign={false}
            areYouSureModal={false}
            width="17.5em"
            height="9.375em"
            closeModal={toggleModalEmpty}
          />
        </div>
      )}
      {modalCancel && (
        <div style={styles.modal}>
          <Modal
            text="Usuário não foi cadastrado."
            hasWarningSign={false}
            areYouSureModal={false}
            width="17.5em"
            height="9.375em"
            closeModal={closeModalChangeScreen}
          />
        </div>
      )}
      {modalSuccess && (
        <div style={styles.modal}>
          <Modal
            text="Usuário cadastrado com sucesso."
            hasWarningSign={false}
            areYouSureModal={false}
            width="17.5em"
            height="9.375em"
            closeModal={() => navigate(-1)}
          />
        </div>
      )}
    </div>
  );
}

FormComponent.defaultProps = defaultProps;

export default FormComponent;
