import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import React from 'react';
import { useNavigate } from 'react-router-dom';

import colors from '../utils/colors';
import fontawesome from '../utils/fontawesome';

const defaultProps = {
  className: 'header',
  enableBars: false,
  text: 'Área do Professor',
  disableText: true,
  buttonColor: colors.theme.iconHeader,
  disableArrow: true,
  onClickBars: () => {
    console.log('clicou');
  },
  enableLogout: false,
};

type HeaderProps = {
  className?: string;
  enableBars?: boolean;
  text?: string;
  disableText?: boolean;
  buttonColor?: string;
  disableArrow?: boolean;
  onClickBars?: () => void;
  enableLogout?: boolean;
} & typeof defaultProps;

function Header(props: HeaderProps) {
  const navigate = useNavigate();
  const {
    className,
    enableBars,
    text,
    disableText,
    buttonColor,
    disableArrow,
    onClickBars,
    enableLogout,
  } = props;

  const styles = {
    header: {
      width: 'auto',
      height: '6.25em',
      background: colors.theme.blue,
      display: 'flex',
      justifyContent: 'space-around',
      alignItems: 'center',
      alignContent: 'center',
      borderRadius: '0px 0px 10px 10px',
    },
    text: {
      color: colors.theme.white,
      fontStyle: 'roboto',
      fontWeight: 'bold',
      fontSize: '1.5em',
      position: 'absolute' as const,
      marginBottom: '0em',
    },
    button: {
      color: `${buttonColor}`,
      height: '1.875em',
      marginRight: 'auto',
      paddingLeft: '5%',
      width: '1.875em',
    },
    buttonLogout: {
      color: `${buttonColor}`,
      height: '1em',
      marginLeft: 'auto',
      paddingRight: '5%',
      alignItems: 'flex-start',
      justifyContent: 'flex-end',
    },
  };

  return (
    <div className={className} style={styles.header}>
      {disableArrow && (
        <FontAwesomeIcon
          icon={fontawesome.icons.faArrowLeft}
          style={styles.button}
          onClick={() => navigate(-1)}
        />
      )}
      {disableText && <h1 style={styles.text}>{text}</h1>}
      {enableBars && (
        <FontAwesomeIcon
          icon={fontawesome.icons.faBars}
          style={styles.button}
          onClick={onClickBars}
        />
      )}
      {enableLogout && (
        <FontAwesomeIcon
          icon={fontawesome.icons.faSignOut}
          style={styles.buttonLogout}
          onClick={() => navigate('/')}
        />
      )}
    </div>
  );
}

Header.defaultProps = defaultProps;

export default Header;
