import { IconDefinition } from '@fortawesome/free-regular-svg-icons';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import React, { useState } from 'react';

import { ButtonCard } from '../components';
import colors from '../utils/colors';
import fontawesome from '../utils/fontawesome';

const defaultProps = {
  className: 'className',
  backgroundColor: colors.theme.light_blue,
  textColor: colors.theme.iconHeader,
  text: 'Tem certeza que deseja excluir esse usuario?',
  textSize: '1em',
  width: '17.5em',
  height: '21.75em',
  marginTop: '14.8125em',
  areYouSureModal: !false,
  textMargin: '0.5em 0 1.5em 0',
  hasWarningSign: true,
  icon: fontawesome.icons.faRectangleXmark,
  closeModal: () => {
    console.log('close');
  },
};

type ModalProps = {
  className?: string;
  width?: string;
  height?: string;
  backgroundColor?: string;
  text?: string;
  textColor?: string;
  textSize?: string;
  textMargin?: string;
  icon?: IconDefinition;
  areYouSureModal?: boolean;
  hasWarningSign?: boolean;
  marginTop?: string;
  closeModal?: () => void;
} & typeof defaultProps;

function Modal(props: ModalProps) {
  const {
    className,
    width,
    height,
    backgroundColor,
    text,
    textColor,
    textSize,
    textMargin,
    icon,
    areYouSureModal,
    hasWarningSign,
    marginTop,
    closeModal,
  } = props;

  const styles = {
    container: {
      display: 'flex',
      justifyContent: 'center',
    },

    modal: {
      backgroundColor,
      color: textColor,
      fontSize: textSize,
      fontStyle: 'roboto',
      fontWeight: '500',
      width,
      height,
      borderRadius: '0.3125em',
      marginTop,
      icon,
    },
    icon: {
      paddingLeft: '0.75em',
      paddingTop: '0.75em',
      height: '1.875em',
    },
    text: {
      paddingLeft: '3em',
      paddingRight: '3em',
      textAlign: 'center' as const,
      margin: textMargin,
    },
    warningContainer: {
      display: 'flex',
      justifyContent: 'center',
    },
    buttonsContainer: {
      justifyContent: 'center',
      textAlign: 'center' as const,
    },
    marginButtons: {
      marginTop: '1.625em',
    },

    warningButton: { height: '4.3125em', width: '4.3125em' },

    test: { position: 'relative' as const },
  };

  return (
    <div>
      <div style={styles.container}>
        <div className={className} style={styles.modal}>
          <ButtonCard
            sizeIcon="1.875em"
            height="1.875em"
            width="1.875em"
            icon={icon}
            text=""
            color={textColor}
            onClick={() => closeModal()}
          />
          {hasWarningSign && (
            <div style={styles.warningContainer}>
              <FontAwesomeIcon
                icon={fontawesome.icons.faTriangleExclamation}
                style={styles.warningButton}
              />
            </div>
          )}

          <div style={styles.test}>
            <div style={styles.text}>{text}</div>
          </div>

          {areYouSureModal && (
            <div style={styles.buttonsContainer}>
              <ButtonCard
                sizeIcon="0px"
                text="SIM"
                textSize="0.8125em"
                backgroundColor={colors.theme.confirm}
                fontWeight="900"
                width="12.825em"
                height="3.625em"
                boxShadow="0 3px 3px 0px rgba(0, 0, 0, 0.2)"
              />
              <div style={styles.marginButtons}>
                <ButtonCard
                  sizeIcon="0px"
                  textSize="0.8125em"
                  text="NÃO"
                  backgroundColor={colors.theme.cancel}
                  fontWeight="900"
                  width="12.825em"
                  height="3.625em"
                  boxShadow="0 3px 3px 0px rgba(0, 0, 0, 0.2)"
                />
              </div>
            </div>
          )}
        </div>
      </div>
    </div>
  );
}

Modal.defaultProps = defaultProps;

export default Modal;
