import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import React, { useState } from 'react';

import { TextField } from '../components';
import TitleComponent from '../components/TitleComponent';
import CardLista from '../containers/CardLista';
import Header from '../containers/Header';
import JSONDATA from '../services/DATA_TEST.json';
import colors from '../utils/colors';
import fontawesome from '../utils/fontawesome';

// Fake Data
type Temp = {
  id: number;
  name: string;
  email: string;
  role: string;
};

type User = {
  id: number;
  name: string;
  cpf: string;
  email: string;
  phone_number: string;
  is_admin: boolean;
  create_at: string;
};

type UserListProps = {
  userArray: User[];
};

function UserList() {
  // { userArray }: UserListProps
  const [searchName, setSearchName] = useState<string>('');
  const arrayUsers: Array<Temp> = JSONDATA; // Fake Data

  return (
    <div style={styles.background}>
      <div className="fixed-top">
        <Header text="Área do Coordenador" disableArrow enableLogout />
      </div>
      <div style={styles.titleContainer}>
        <TitleComponent
          text="Buscar Usuário"
          fontWeight="600"
          textSize="1.75rem"
        />
        <FontAwesomeIcon
          icon={fontawesome.icons.faSquarePlus}
          style={styles.icon}
          onClick={() => console.log('Go to the add users page!')}
        />
      </div>
      <div style={styles.searchBar}>
        <TextField
          placeholder="Buscar..."
          margin="0px"
          borderRadius="30px"
          disableIcon={false}
          onChange={(event: React.ChangeEvent<HTMLInputElement>) => {
            setSearchName(event.target.value);
          }}
        />
      </div>
      <div style={styles.userList}>
        {arrayUsers.length !== 0 ? (
          arrayUsers
            .filter(
              testUser =>
                testUser.name.toLowerCase().includes(searchName.toLowerCase()),
              // || testUser.email.toLowerCase().includes(searchName.toLowerCase()),
              // Tirar o email e colocar pelo titulo (prof,especi,responsa)
            )
            .slice(0, 11)
            .map(user => {
              return (
                // Cuidar com o valor da key, usar o id para fazer isso
                <div key={user.id} style={styles.card}>
                  <CardLista
                    titleContent={user.name}
                    subtitle1Content={user.role}
                    enableIconArrow={false}
                    enableSubtitle2={false}
                    enableTag={false}
                  />
                </div>
              );
            })
        ) : (
          <div style={styles.card}>
            <div>Nao tem nenhum usuário cadastrado</div>
          </div>
        )}
      </div>
    </div>
  );
}

const styles = {
  background: {
    background: colors.theme.background,
    minHeight: '145vh',
  },
  titleContainer: {
    display: 'flex',
    justifyContent: 'center',
    paddingTop: '9.5rem',
    paddingBottom: '1.375rem',
  },
  searchBar: {
    display: 'flex',
    justifyContent: 'center',
  },
  icon: {
    fontSize: '2rem',
    marginLeft: '1.75rem',
    cursor: 'pointer',
    paddingTop: '0.3rem',
  },
  userList: {
    display: 'flex',
    flexDirection: 'column' as const,
    alignItems: 'center',
    padding: '2.438rem 0rem',
  },
  card: {
    marginBottom: '1.438rem',
    width: '20.188rem',
  },
};

export default UserList;
